@@ -20,11 +20,11 @@ Net::SNMP::Mixin::Util - helper class for Net::SNMP mixins
 
 =head1 VERSION
 
-Version 0.07_01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -195,17 +195,41 @@ unless ( caller() ) {
 
 L<Net::SNMP>, L<Sub::Exporter>
 
-=head1 BUGS, PATCHES & FIXES
+=head1 BUGS
 
-There are no known bugs at the time of this release. However, if you spot a bug or are experiencing difficulties that are not explained within the POD documentation, please submit a bug to the RT system (see link below). However, it would help greatly if you are able to pinpoint problems or even supply a patch. 
+Please report any bugs or feature requests to
+C<bug-net-snmp-mixin at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-SNMP-Mixin>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
-Fixes are dependant upon their severity and my availablity. Should a fix not be forthcoming, please feel free to (politely) remind me by sending an email to gaissmai@cpan.org .
+=head1 SUPPORT
 
-  RT: http://rt.cpan.org/Public/Dist/Display.html?Name=Net-SNMP-Mixin
+You can find documentation for this module with the perldoc command.
 
-=head1 AUTHOR
+    perldoc Net::SNMP::Mixin::Util
 
-Karl Gaissmaier <karl.gaissmaier at uni-ulm.de>
+You can also look for information at:
+
+=over 4
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Net-SNMP-Mixin>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Net-SNMP-Mixin>
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net-SNMP-Mixin>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Net-SNMP-Mixin>
+
+=back
 
 =head1 COPYRIGHT & LICENSE
 
